@@ -44,3 +44,20 @@ test_that("create_toolset: store_res", {
   toolset2 <- create_toolset("PerfMeas", store_res = FALSE)[[1]]
   expect_equal(environment(toolset2$clone)$private$def_store_res, FALSE)
 })
+
+test_that(".pm_wrapper", {
+  testset <- create_testset("curve", "c1")[[1]]
+  res <- .pm_wrapper(testset)
+
+  expect_equal(res$x, c(0.5, 0.5, 1.0, 1.0))
+  expect_equal(res$y, c(1.0, 0.5, 0.6666667, 0.5), tolerance = .001)
+  expect_true(is.na(res$auc))
+
+  res2 <- .pm_wrapper(testset, store_res = FALSE)
+  expect_true(is.null(res2))
+
+  res3 <- .pm_wrapper(testset, calc_auc = TRUE)
+  expect_equal(res3$x, c(0.5, 0.5, 1.0, 1.0))
+  expect_equal(res3$y, c(1.0, 0.5, 0.6666667, 0.5), tolerance = .001)
+  expect_equal(res3$auc, 0.2916667, tolerance = .001)
+})
